=======================================
``psyclone.psyir.backend.sympy_writer``
=======================================

.. automodule:: psyclone.psyir.backend.sympy_writer

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.backend.sympy_writer
